@@ -99,15 +99,18 @@ class TimedProgress:
         
         if self.SHOW_PROGRESS:
             # terminate if we havent already terminated
-            self.p.terminate()
-            self.p.join()
-            self.p.close()
-
-            # clear whole terminal line
             try:
-                sys.stdout.write('\r{}{}\r'.format((' ' * TERM_WIDTH()), ANSI['reset']))
-            except (IOError, BrokenPipeError):
-                # ignore when the parent proc has stopped listening to our stdout
+                self.p.terminate()
+                self.p.join()
+                self.p.close()
+
+                # clear whole terminal line
+                try:
+                    sys.stdout.write('\r{}{}\r'.format((' ' * TERM_WIDTH()), ANSI['reset']))
+                except (IOError, BrokenPipeError):
+                    # ignore when the parent proc has stopped listening to our stdout
+                    pass
+            except ValueError:
                 pass
 
 
@@ -466,7 +469,10 @@ def printable_folders(folders: Dict[str, Optional["Link"]],
         from .index.csv import links_to_csv
         return links_to_csv(folders.values(), cols=csv.split(','), header=True)
     
-    return '\n'.join(f'{folder} {link}' for folder, link in folders.items())
+    return '\n'.join(
+        f'{folder} {link and link.url} "{link and link.title}"'
+        for folder, link in folders.items()
+    )
 
 
 
